@@ -1,7 +1,8 @@
 import logging
+from typing import List
 
 
-def list_replace(lst: list, old, new) -> None:
+def list_replace(lst: List, old, new) -> None:
     """
     replace list elements (inplace)
     """
@@ -14,13 +15,15 @@ def list_replace(lst: list, old, new) -> None:
         pass
 
 
-def calc_hash(lst: list) -> str:
+def calc_hash(lst: List) -> str:
     """
     Internal use only.
-    Calculates md5sum of given command with it's byte-string.
+    Calculates sha1sum of given command with it's byte-string.
+    This is for non-cryptographic purpose,
+    that's why a faster and insecure hashing algorithm is chosen.
     """
     to_hash = " ".join(lst).encode("ascii")
-    return __import__("hashlib").md5(to_hash).hexdigest()
+    return __import__("hashlib").sha1(to_hash).hexdigest()[:12]
 
 
 def get_logger() -> logging.Logger:
